<?php

declare(strict_types=1);

namespace Drupal\mcp\Controller;

use Drupal\Core\Utility\Error;
use Drupal\jsonrpc\Exception\JsonRpcException;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\jsonrpc\Controller\HttpController;
use Symfony\Component\HttpFoundation\Request;

/**
 * Returns responses for Model Context Protocol routes.
 */
class McpController extends HttpController {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->handler = $container->get('mcp.jsonrpc.handler');

    return $instance;
  }

  /**
   * Post endpoint for receiving messages from the client.
   */
  public function post(Request $request) {
    try {
      return $this->resolve($request);
    }
    catch (\Exception $e) {
      Error::logException(
        $this->getLogger('mcp'),
        $e,
        'An error occurred while handling the response: @message',
        [
          '@message' => $e->getMessage(),
        ]
      );

      return $this->exceptionResponse(
        JsonRpcException::fromPrevious($e)
      );
    }
  }

}
